==> MediaPipeTools-1.1.2.tar.gz: MediaPipeTools-1.1.2/setup.py <==
from distutils.core import setup

setup(
  name = 'MediaPipeTools',         # How you named your package folder (MyLib)
  packages = ['MediaPipeTools'],   # Chose the same as "name"
  version = '1.1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This package will help you use mediapipe tools easily',
  long_description="Mediapipe tools to use mediapipe library easily. Provides had tracking, face mesh and pose tracking. For more info see the repository https://github.com/chinmay18030/MediapipeTools",
  author = 'Ace Tech Academy',                   # Type in your name
  author_email = 'aceteachacademy@gmail.com',      # Type in your E-Mail
  keywords = ['Mediapipe Tools', 'FaceMesh', 'hand tracking','pose tracking'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'opencv-python',
          'mediapipe',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.6',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> MediaPipeTools-1.3.tar.gz: MediaPipeTools-1.3/setup.py <==
from distutils.core import setup

setup(
  name = 'MediaPipeTools',         # How you named your package folder (MyLib)
  packages = ['MediaPipeTools'],   # Chose the same as "name"
  version = '1.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This package will help you use mediapipe tools easily',
  long_description="Mediapipe tools to use mediapipe library easily. Provides had tracking, face mesh and pose tracking. For more info see the repository https://github.com/chinmay18030/MediapipeTools",
  author = 'Ace Tech Academy',                   # Type in your name
  author_email = 'aceteachacademy@gmail.com',      # Type in your E-Mail
  keywords = ['Mediapipe Tools', 'FaceMesh', 'hand tracking','pose tracking',"virtual background","whole body track"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'opencv-python',
          'mediapipe',
          "numpy"
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.6',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
